@@ -1,7 +1,7 @@
 ##/*****************************************************************************
 ## * SIENA: Simulation Investigation for Empirical Network Analysis
 ## *
-## * Web: http://www.stats.ox.ac.uk/~snijders/siena
+## * Web: https://www.stats.ox.ac.uk/~snijders/siena
 ## *
 ## * File: phase1.r
 ## *
@@ -216,7 +216,7 @@ phase1.2 <- function(z, x, ...)
 	    z$dfra[outer(z$fixed, z$fixed, '|')] <- 0
 	    diag(z$dfra)[z$fixed] <- 1.0
 	    z$mnfra[z$fixed] <- 0.0
-	    z$sf[ , z$fixed] <- 0	    
+	    z$sf[ , z$fixed] <- 0
 	  }
 	  else
 	  {
@@ -224,7 +224,7 @@ phase1.2 <- function(z, x, ...)
 	    z$dfra[outer(z$fixed & !z$gmmEffects, z$fixed & !z$gmmEffects, '|')] <- 0
 	    diag(z$dfra)[z$fixed & !z$gmmEffects] <- 1.0
 	    z$mnfra[z$fixed & !z$gmmEffects] <- 0.0
-	    z$sf[ , z$fixed & !z$gmmEffects] <- 0		    
+	    z$sf[ , z$fixed & !z$gmmEffects] <- 0
 	  }
 	}
 	# Manage derivative matrix
@@ -255,14 +255,14 @@ phase1.2 <- function(z, x, ...)
 		}
 	}
 	else if (z$gmm)
-	{ 
+	{
 	  # qxq covariance matrix of the statistics
 	  sigmagmm <- cov(t(apply(z$sf2, 1, function(x) colSums(x)) - z$targets))
 	  W <- solve(sigmagmm) # Matrix of GMoM weights
 	  gamma <- z$dfra[,-which(z$gmmEffects==TRUE)] # gammaT qxp matrix of first order derivatives
 	  B0 <- t(gamma) %*% W
 	  B <- solve(diag(sqrt(rowSums(B0*B0)))) %*% B0 # Row-normlized matrix B
-	  D0 <- B %*% gamma # Matrix D = B * gammaT 
+	  D0 <- B %*% gamma # Matrix D = B * gammaT
 	  if (inherits(try(dinvGmm <- solve(D0), silent=TRUE), "try-error"))
 	  {
 	    Report('Error message for inversion of dfra: \n', cf)
@@ -296,7 +296,7 @@ phase1.2 <- function(z, x, ...)
 	}
 	# Partial diagonalization of derivative matrix
 	# for use if 0 < x$diagonalize < 1.
-	if (!z$gmm) 
+	if (!z$gmm)
 	{
 	  temp <- (1-x$diagonalize)*z$dfra +
 	    x$diagonalize*diag(diag(z$dfra), nrow=dim(z$dfra)[1])
@@ -307,7 +307,7 @@ phase1.2 <- function(z, x, ...)
 	  z$dinvv <- solve(temp)
 	}
 	else
-	{	  
+	{
 	  temp <- (1-x$diagonalize)*dinvGmm +
 	    x$diagonalize*diag(diag(dinvGmm), nrow=dim(dinvGmm)[1])
 	  temp[which(z$fixed & !z$gmmEffects), ] <- 0.0
@@ -332,14 +332,14 @@ phase1.2 <- function(z, x, ...)
 			format(0.5 * x$firstg, digits = 5, nsmall = 5, width = 8), '.\n'),
 		cf, sep='')
 	fchange <- 0.5 * x$firstg * fchange
-	if (!z$gmm) 
+	if (!z$gmm)
 	{
 	fchange[z$fixed] <- 0.0
 	}
 	else
 	{
 	  fchange[which(z$fixed & !z$gmmEffects)] <- 0.0
-	}	
+	}
 	##check if jump is too large
 	maxrat<- max(abs(fchange / z$scale))
 	if (maxrat > 10.0)
@@ -391,9 +391,13 @@ CalculateDerivative <- function(z, x)
 	{
 		##note that warnings is never set as this piece of code is not executed
 		##if force_fin_diff_phase_1 is true so warning is zero on entry
-		##browser()
 		dfra <- derivativeFromScoresAndDeviations(z$ssc, z$sf2,
 			z$dfras, z$sscs, z$sf2s, z$sf2.byIteration, z$Phase1nits)
+		if (sum(z$f$types == "continuous") > 1) {
+		  stop("Analytic sde derivate in phase 1 not implemented for >1 continuous behavior")
+		} else if (sum(z$f$types == "continuous") == 1) {
+		  dfra <- updateDerivativeSde(z, dfra)
+		}
 		fromBayes <- 'fromBayes' %in% names(x)
 		z$jacobianwarn1 <- rep(FALSE, z$pp)
 		if ((any(diag(dfra)[!z$fixed] <= 0)) && (!fromBayes))
@@ -430,12 +434,12 @@ CalculateDerivative <- function(z, x)
 			return(z)
 		}
 	}
-	if (!z$gmm) 
+	if (!z$gmm)
   	{
 		dfra[outer(z$fixed,z$fixed,'|')] <- 0
 		diag(dfra)[z$fixed] <- 1.0
-  	} 
-  	else 
+  	}
+  	else
   	{
     	dfra[outer(z$fixed & !z$gmmEffects, z$fixed & !z$gmmEffects,'|')] <- 0
     	diag(dfra)[z$fixed & !z$gmmEffects] <- 1.0
@@ -557,9 +561,10 @@ derivativeFromScoresAndDeviations <- function(scores, deviations, sumdfra,
 				dfra <- dfra + outer(scores[i, j, ], deviations[i, j, ])
 			}
 		}
-		tmp <- matrix(sapply(1 : nWaves, function(i)
+		tmp <- matrix(vapply(1 : nWaves, function(i){
 				outer(colMeans(deviations)[i,],
-					colMeans(scores)[i,])), ncol=nWaves)
+					colMeans(scores)[i,])}, 
+					FUN.VALUE=matrix(0,nParameters,nParameters)), ncol=nWaves)
 		dfra <- t(dfra) / nIterations
 	}
 	else
@@ -567,14 +572,83 @@ derivativeFromScoresAndDeviations <- function(scores, deviations, sumdfra,
 		nWaves <- dim(sumscores)[1]
 		nParameters <- dim(sumscores)[2]
 		dfra <- sumdfra
-		tmp <- matrix(sapply(1 : nWaves,
-				function(i){outer(sumdeviations[i,], sumscores[i,])}),
-			ncol=nWaves) / (nIter^2)
+		tmp <- matrix(vapply(1 : nWaves,
+				function(i){outer(sumdeviations[i,], sumscores[i,])},
+				FUN.VALUE=matrix(0,nParameters,nParameters)),
+						ncol=nWaves) / (nIter^2)
 		dfra <- t(dfra) / nIter
 	}
 	dfra - matrix(rowSums(tmp), nrow=nParameters)
 }
 
+##@updateDerivativeSde siena07 replace dfra estimates for sde parameters by analytic approx.
+updateDerivativeSde <- function(z, dfra)
+{
+  wienerId <- which(vapply(z$effects$effectName, 
+			function(x){grepl("wiener", x, fixed = TRUE)}, FUN.VALUE=TRUE))
+  feedbackId <- which(vapply(z$effects$effectName, 
+			function(x){grepl("feedback from", x, fixed = TRUE)}, FUN.VALUE=TRUE))
+  interceptId <- which(vapply(z$effects$effectName, 
+			function(x){grepl("intercept", x, fixed = TRUE)}, FUN.VALUE=TRUE))
+  scaleId <- which(z$effects$name == "sde")
+  onePeriodSde <- (length(wienerId) > 0) # option set by the user
+  nPeriods <- z$observations - 1
+  n <- length(z$f$Data1$nodeSets$Actors)
+    
+  g <- ifelse(onePeriodSde, z$effects$initialValue[wienerId], 1)
+  a <- z$effects$initialValue[feedbackId]
+  b <- z$effects$initialValue[interceptId]
+  tau <- z$effects$initialValue[scaleId]
+  y <- z$f$Data1$contbehavs[[1]][[1]]
+
+  if (onePeriodSde) {
+    dfra[c(wienerId, feedbackId, interceptId), c(wienerId, feedbackId, interceptId)] <- 0
+  } else {
+    dfra[c(feedbackId, interceptId, scaleId), c(feedbackId, interceptId, scaleId)] <- 0
+  } 
+  
+  for (i in 1:nPeriods) 
+  {
+    dSa_da <- sum(y[,i+1] * (tau[i] * exp(a*tau[i]) * y[,i] + 
+                  (1 + a*tau[i]*exp(a*tau[i]) - exp(a*tau[i])) * b / (a^2)))
+    dSa_db <- sum((exp(a*tau[i])-1)/a * y[,i+1])
+    dSa_dg <- 0
+    dSa_dt <- sum(exp(a*tau[i]) * (b + a * y[,i]) * y[,i+1])
+    
+    dSb_da <- sum(tau[i] * exp(a*tau[i]) * y[,i] + 
+                  (1 + a*tau[i]*exp(a*tau[i]) - exp(a*tau[i])) * b / (a^2))
+    dSb_db <- n * (exp(a*tau[i])-1)/a 
+    dSb_dg <- 0
+    dSb_dt <- sum(exp(a*tau[i]) * (b + a * y[,i]))
+    
+    dSgt_da <- sum(1/(2*a^3) * (-4*b^2 + a*g^2 - 4*a*b*y[,i] - 4*exp(a*tau[i])*(b+a*y[,i]) *
+                   (b * (-2+a*tau[i]) + a^2*tau[i]*y[,i]) + exp(2*a*tau[i]) *
+                   (-4*b^2 + 4*a^3*tau[i]*y[,i]^2 + 2*a^2*tau[i]*(g^2 + 4*b*y[,i]) - 
+                   a * (g^2 + 4*b*(-b*tau[i] + y[,i])))))
+    dSgt_db <- sum(1/(a^2) * (2*(-1+exp(a*tau[i]))^2 * (b+a*y[,i])))
+    dSgt_dg <- n * (exp(2*a*tau[i])-1) * g / a
+    dSgt_dt <- sum((-2*exp(a*tau[i])*(b + a*y[,i])^2 + 
+                    exp(2*a*tau[i])*(2*b^2 + a*(g^2 + 2*y[,i]*(2*b + a*y[,i])))) / a)
+
+    if (onePeriodSde) 
+    {
+      dfra[wienerId, c(wienerId, feedbackId, interceptId)] <- c(dSgt_dg, dSgt_da, dSgt_db)
+      dfra[feedbackId, c(wienerId, feedbackId, interceptId)] <- c(dSa_dg, dSa_da, dSa_db)
+      dfra[interceptId, c(wienerId, feedbackId, interceptId)] <- c(dSb_dg, dSb_da, dSb_db)
+    }
+    else
+    {
+      dfra[feedbackId, c(feedbackId, interceptId, scaleId[i])] <- 
+        dfra[feedbackId, c(feedbackId, interceptId, scaleId[i])] + c(dSa_da, dSa_db, dSa_dt)
+      dfra[interceptId, c(feedbackId, interceptId, scaleId[i])] <- 
+        dfra[interceptId, c(feedbackId, interceptId, scaleId[i])] + c(dSb_da, dSb_db, dSb_dt)
+      dfra[scaleId[i], c(feedbackId, interceptId, scaleId[i])] <- 
+        dfra[scaleId[i], c(feedbackId, interceptId, scaleId[i])] + c(dSgt_da, dSgt_db, dSgt_dt)
+    }
+  }
+  dfra
+}
+
 ##@makeZsmall siena07 create a minimal version of z to pass between processors.
 makeZsmall <- function(z)
 {
@@ -630,10 +704,22 @@ createSiena07stores <- function(z, nIterations, f)
 	if (!z$sf2.byIteration){ z$ssc <- NULL}
 	if (z$maxlike)
 	{
-		## misdat steps are separated out giving 9 types
-		z$accepts <- array(0, dim=c(nIterations, z$nDependentVariables, 9))
-		z$rejects <- array(0, dim=c(nIterations, z$nDependentVariables, 9))
-		z$aborts <- array(0, dim=c(nIterations, z$nDependentVariables, 9))
+		## misdat steps are separated out giving 10 types
+		z$accepts <- array(0, dim=c(nIterations, z$nDependentVariables, 10))
+		z$rejects <- array(0, dim=c(nIterations, z$nDependentVariables, 10))
+		z$aborts <- array(0, dim=c(nIterations, z$nDependentVariables, 10))
+		dimnames(z$accepts) <- list(NULL, NULL,
+				c("InsDiag", "CancDiag", "Permute", "InsPerm",
+				"DelPerm", "InsMiss",
+				"DelMiss", "InsMisdat", "DelMisdat", "Move"))
+		dimnames(z$rejects) <- list(NULL, NULL,
+				c("InsDiag", "CancDiag", "Permute", "InsPerm",
+				"DelPerm", "InsMiss",
+				"DelMiss", "InsMisdat", "DelMisdat", "Move"))
+		dimnames(z$aborts) <- list(NULL, NULL,
+				c("InsDiag", "CancDiag", "Permute", "InsPerm",
+				"DelPerm", "InsMiss",
+				"DelMiss", "InsMisdat", "DelMisdat", "Move"))
 	}
 	z$npos <- rep(0, z$pp)
 	if (!is.null(z$cconditional) && z$cconditional)
