@@ -240,8 +240,11 @@ sienaDataCreate<- function(..., nodeSets=NULL, getDocumentation=FALSE)
 	if (length(dots) == 1)
 	{
 		ldots <- list(...)
-		dotsIsList <- (is.list(ldots[[1]]))
+		dotsIsList <- ((is.list(ldots[[1]])) & 
+						(! inherits((ldots[[1]]), "sienaDependent")))
 # If dotsIsList, it needs to be a list of variables
+# The second condition is to rule out the case of a single dependent network
+# given as a list of sparse matrices.
 		if (dotsIsList) 
 		{
 			dots <- as.list(substitute(...))[-1]
@@ -616,6 +619,14 @@ sienaDataCreate<- function(..., nodeSets=NULL, getDocumentation=FALSE)
 	types <- sapply(depvars, function(x)attr(x, "type"))
 	depvars <- depvars[c(which(!(types %in% c('behavior', 'continuous'))),
 						which(types == 'behavior'), which(types == "continuous"))]
+	onemodes <- which(types == "oneMode")
+	bipartites <- which(types == "bipartite")
+	onemodes.mx <- max(c(onemodes, 0))
+	bipartites.mn <- min(c(bipartites, v1+1))
+	if (bipartites.mn < onemodes.mx)
+	{
+		stop("One-mode networks (if any) should be given before bipartite networks (if any).")
+	}
 
 	for (i in 1:v1) ## dependent variables
 	{
@@ -2396,8 +2407,9 @@ getGroupNetRanges <- function(data)
 					varmax <- max(varmax, sapply(depvar, function(x)
 											 {
 												 tmp <- x@x
+												 ifelse(length(tmp)==0,0,
 												 max(tmp[!(is.na(tmp) |
-														   tmp %in% c(10, 11))])
+														   tmp %in% c(10, 11))]))
 											 }), na.rm=TRUE)
 				}
 				else
