@@ -256,7 +256,14 @@ coDyadCovar<- function(val, centered=TRUE, nodeSets=c("Actors","Actors"),
             stop("val must be numeric or a factor")
         }
     }
-    else
+	if ((!is.factor(val)) & warn)
+	{
+		if (max(val, na.rm=TRUE) == min(val, na.rm=TRUE))
+		{
+			warning('Note: all values are identical to ', max(val, na.rm=TRUE),'.')
+		}
+	}
+    if (sparse)
     {
         if (!inherits(val, "TsparseMatrix"))
         {
@@ -268,13 +275,6 @@ coDyadCovar<- function(val, centered=TRUE, nodeSets=c("Actors","Actors"),
 	{
 		warning('Note: all values are missing.')
 	}
-	if (!is.factor(val))
-	{
-		if ((var(as.vector(val), na.rm=TRUE)==0) & warn)
-		{
-			warning('Note: all values are identical to ', mean(as.vector(val), na.rm=TRUE),'.')
-		}
-	}
     vardims <- dim(val)
     if (length(nodeSets) > 2)
     {
@@ -336,6 +336,13 @@ varDyadCovar<- function(val, centered=TRUE, nodeSets=c("Actors","Actors"),
         if (!(is.numeric(val) || is.factor(val)))
             stop("val must be numeric or a factor")
         vardims <- dim(val)
+		if ((!is.factor(val)) & warn)
+		{
+			if (max(val, na.rm=TRUE) == min(val, na.rm=TRUE))
+			{
+				warning('Note: all values are identical to ', max(val, na.rm=TRUE),'.')
+			}
+		}
     }
     else
     {
@@ -348,19 +355,11 @@ varDyadCovar<- function(val, centered=TRUE, nodeSets=c("Actors","Actors"),
             stop("all matrices must have the same dimension")
         vardims <- vardims[, 1]
         vardims[3] <- length(val)
-
     }
 	if ((sum(!is.na(val))==0) & warn)
 	{
 		warning('Note: all values are missing.')
 	}
-	if ((!is.factor(val)) & warn)
-	{
-		if (var(as.vector(val), na.rm=TRUE)==0)
-		{
-			warning('Note: all values are identical to ', mean(as.vector(val), na.rm=TRUE),'.')
-		}
-	}
     if (length(nodeSets) > 2)
         stop("nodeSets may only have one or two elements")
     if (!is.character(nodeSets))
