@@ -36,7 +36,7 @@ protected:
 
 private:
 	// A helper array of marks for statistic calculation
-	int * lmark;
+	int * lmark {};
 };
 
 }
