@@ -15,6 +15,8 @@
 #include "utils/SqrtTable.h"
 #include "network/Network.h"
 #include "model/variables/NetworkVariable.h"
+#include "model/EffectInfo.h"
+#include "data/Data.h"
 
 using namespace std;
 
@@ -25,12 +27,37 @@ namespace siena
  * Constructor.
  */
 IndegreeActivityEffect::IndegreeActivityEffect(
-	const EffectInfo * pEffectInfo, bool root) : NetworkEffect(pEffectInfo)
+	const EffectInfo * pEffectInfo, bool root, bool centered):
+										NetworkEffect(pEffectInfo)
 {
 	this->lroot = root;
 	this->lsqrtTable = SqrtTable::instance();
+	this->lcentered = centered;
+	this->lcentering = 0.0;
+	this->lvariableName = pEffectInfo->variableName();
+// centering and root cannot occur simultaneously
 }
 
+/**
+ * Initializes this function.
+ * @param[in] pData the observed data
+ * @param[in] pState the current state of the dependent variables
+ * @param[in] period the period of interest
+ * @param[in] pCache the cache object to be used to speed up calculations
+ */
+void IndegreeActivityEffect::initialize(const Data * pData,
+	State * pState,
+	int period,
+	Cache * pCache)
+{
+	NetworkEffect::initialize(pData, pState, period, pCache);
+	if (this->lcentered)
+	{
+		NetworkLongitudinalData * pNetworkData =
+				pData->pNetworkData(this->lvariableName);
+		this->lcentering = pNetworkData->averageInDegree();
+	}
+}
 
 /**
  * Calculates the contribution of a tie flip to the given actor.
@@ -38,7 +65,7 @@ IndegreeActivityEffect::IndegreeActivityEffect(
 double IndegreeActivityEffect::calculateContribution(int alter) const
 {
 	double change =
-		this->pNetwork()->inDegree(this->ego());
+		this->pNetwork()->inDegree(this->ego()) - this->lcentering;
 
 	if (this->lroot)
 	{
@@ -58,7 +85,7 @@ double IndegreeActivityEffect::tieStatistic(int alter)
 {
 	const Network * pNetwork = this->pNetwork();
 	int inDegree = pNetwork->inDegree(this->ego());
-	double statistic = inDegree;
+	double statistic = inDegree - this->lcentering;;
 
 	if (this->lroot)
 	{
@@ -81,7 +108,7 @@ double IndegreeActivityEffect::endowmentStatistic(Network * pLostTieNetwork)
 	for (int i = 0; i < n; i++)
 	{
 		int indeg = pStart->inDegree(i);
-		double rindeg = indeg;
+		double rindeg = indeg - this->lcentering;
 		if (this->lroot)
 		{
 			rindeg = this->lsqrtTable->sqrt(indeg);
