@@ -54,13 +54,13 @@ protected:
 
 private:
 	// Indicates if the square root of outdegrees must be used
-	bool lroot;
+	bool lroot {};
 
 	// Lookup table for fast square root calculations
 	SqrtTable * lsqrtTable;
-	bool lcentered;
-	double lcentering;
-	string lvariableName;
+	bool lcentered {};
+	double lcentering {};
+	string lvariableName {};
 };
 
 }
