@@ -37,8 +37,8 @@ public:
 	virtual double egoStatistic(int ego, double * currentValues);
 
 private:
-	bool laverage;
-	bool lalterPopularity;
+	bool laverage {};
+	bool lalterPopularity {};
 };
 
 }
