@@ -27,9 +27,9 @@ public:
 	virtual double value(int alter) const;
 
 private:
-	bool lexcludeMissing;
-	bool loutgoing;
-	bool ltrunc;
+	bool lexcludeMissing {};
+	bool loutgoing {};
+	bool ltrunc {};
 };
 
 }
