@@ -31,8 +31,8 @@ public:
 	virtual double value(int alter) const;
 
 private:
-	bool lexcludeMissing;
-	bool ltotal;
+	bool lexcludeMissing {};
+	bool ltotal {};
 };
 
 }
