@@ -12,6 +12,7 @@
 #include "MixedTwoStepFunction.h"
 #include <stdexcept>
 #include <cstdlib>
+#include <cmath>
 #include "utils/SqrtTable.h"
 #include "model/tables/TwoNetworkCache.h"
 #include "model/tables/MixedEgocentricConfigurationTable.h"
@@ -36,8 +37,8 @@ MixedTwoStepFunction::MixedTwoStepFunction(std::string firstNetworkName,
 	this->lpTable = 0;
 	this->ldirection1 = firstDirection;
 	this->ldirection2 = secondDirection;
-	this->lroot = (std::abs(par-2) < 0.001);
-	this->ltrunc = (std::abs(par-3) < 0.001);
+	this->lroot = (fabs(par-2) < 0.001);
+	this->ltrunc = (fabs(par-3) < 0.001);
 	this->lsqrtTable = SqrtTable::instance();
 }
 
@@ -83,7 +84,7 @@ void MixedTwoStepFunction::initialize(const Data * pData,
  * that the function has been initialized before and pre-processed with
  * respect to a certain ego.
  */
-double MixedTwoStepFunction::value(int alter)
+double MixedTwoStepFunction::value(int alter) const
 {
 	if (this->lroot)
 	{
