@@ -32,9 +32,9 @@ public:
 	virtual double value(int alter) const;
 
 private:
-	bool lexcludeMissing;
-	bool lsameValue;
-	bool lsameVariable;
+	bool lexcludeMissing {};
+	bool lsameValue {};
+	bool lsameVariable {};
 };
 
 }
