@@ -15,8 +15,7 @@
  */
 #include <vector>
 #include <cstring>
-#include <Rinternals.h>
-#undef length
+// #include <Rinternals.h> // included by siena07internals.h
 #include "siena07internals.h"
 #include "data/Data.h"
 #include "data/LongitudinalData.h"
@@ -43,6 +42,7 @@
 #include "network/layers/PrimaryLayer.h"
 #include "network/TieIterator.h"
 #include "utils/Utils.h"
+#include <Rinternals.h>
 
 
 using namespace std;
@@ -147,64 +147,64 @@ void getColNos(SEXP Names, int * netTypeCol, int * nameCol, int * effectCol,
 	}
 	if (*netTypeCol < 0)
 	{
-		error("cannot find nettype");
+		Rf_error("cannot find nettype");
 	}
 	if (*nameCol < 0)
 	{
-		error("cannot find network name");
+		Rf_error("cannot find network name");
 	}
 	if (*effectCol < 0)
 	{
-		error("cannot find effectName");
+		Rf_error("cannot find effectName");
 	}
 	if (*parmCol < 0)
 	{
-		error("cannot find internal parameter");
+		Rf_error("cannot find internal parameter");
 	}
 	if (*int1Col < 0)
 	{
-		error("cannot find interaction1");
+		Rf_error("cannot find interaction1");
         }
 
 	if (*int2Col < 0)
 	{
-		error("cannot find interaction2");
+		Rf_error("cannot find interaction2");
 	}
 	if (*initValCol < 0)
 	{
-		error("cannot find initial value");
+		Rf_error("cannot find initial value");
 	}
 	if (*groupCol < 0)
 	{
-		error("cannot find group");
+		Rf_error("cannot find group");
 	}
 	if (*periodCol < 0)
 	{
-		error("cannot find period");
+		Rf_error("cannot find period");
 	}
 	if (*pointerCol < 0)
 	{
-		error("cannot find effect pointer");
+		Rf_error("cannot find effect pointer");
 	}
 	if (*rateTypeCol < 0)
 	{
-		error("cannot find rate type");
+		Rf_error("cannot find rate type");
 	}
 	if (*intptr1Col < 0)
 	{
-		error("cannot find effect1");
+		Rf_error("cannot find effect1");
 	}
 	if (*intptr2Col < 0)
 	{
-		error("cannot find effect2");
+		Rf_error("cannot find effect2");
 	}
 	if (*intptr3Col < 0)
 	{
-		error("cannot find effect3");
+		Rf_error("cannot find effect3");
 	}
 	if (*settingCol < 0)
 	{
-		error("cannot find setting col; reconstruct effects object with this version of RSiena");
+		Rf_error("cannot find setting col; reconstruct effects object with this version of RSiena");
 	}
 	//Rprintf("%d parmcol\n", *parmCol);
 }
@@ -217,8 +217,8 @@ void updateParameters(SEXP EFFECTSLIST, SEXP THETA, vector<Data *> *
 {
 	// get the column names from the names attribute
 	SEXP cols;
-	PROTECT(cols = install("names"));
-	SEXP Names = getAttrib(VECTOR_ELT(EFFECTSLIST, 0), cols);
+	PROTECT(cols = Rf_install("names"));
+	SEXP Names = Rf_getAttrib(VECTOR_ELT(EFFECTSLIST, 0), cols);
 
 	int netTypeCol; /* net type */
 	int nameCol; /* network name */
@@ -304,13 +304,13 @@ void updateParameters(SEXP EFFECTSLIST, SEXP THETA, vector<Data *> *
 				 	}
 				 	else
 				 	{
-				 		error("setting found for behavior variable %s",
+				 		Rf_error("setting found for behavior variable %s",
 				 			networkName);
 				 	}
 				}
 			}
 			else if (strcmp(effectType, "rate") == 0 &&
-					 strcmp(effectName, "scale") == 0)		
+					 strcmp(effectName, "scale") == 0)
 			{
 				int period = INTEGER(VECTOR_ELT(EFFECTS, periodCol))[eff] - 1;
 				if (strcmp(setting, "") == 0)
@@ -319,7 +319,7 @@ void updateParameters(SEXP EFFECTSLIST, SEXP THETA, vector<Data *> *
 				}
 			else
 			{
-					error("setting found for behavior variable %s", 
+					Rf_error("setting found for behavior variable %s", 
 						networkName);
 				}
 			}
@@ -353,7 +353,7 @@ void setupOneModeNetwork(SEXP ONEMODE,
 	//Rprintf("%x\n", pNetworkData);
 	SEXP ONEMODEVALS = VECTOR_ELT(ONEMODE, 0);
 	int *start = INTEGER(ONEMODEVALS);
-	int listlen = ncols(ONEMODEVALS);
+	int listlen = Rf_ncols(ONEMODEVALS);
 	int pos = 0;
 
 	for (int row = 0; row < listlen; row++)
@@ -371,7 +371,7 @@ void setupOneModeNetwork(SEXP ONEMODE,
 
 	ONEMODEVALS = VECTOR_ELT(ONEMODE, 1);
 	start = INTEGER(ONEMODEVALS);
-	listlen = ncols(ONEMODEVALS);
+	listlen = Rf_ncols(ONEMODEVALS);
 	pos = 0;
 
 	for (int row = 0; row < listlen; row++)
@@ -389,7 +389,7 @@ void setupOneModeNetwork(SEXP ONEMODE,
 
 	ONEMODEVALS = VECTOR_ELT(ONEMODE, 2);
 	start = INTEGER(ONEMODEVALS);
-	listlen = ncols(ONEMODEVALS);
+	listlen = Rf_ncols(ONEMODEVALS);
 	pos = 0;
 
 	for (int row = 0; row < listlen; row++)
@@ -415,16 +415,14 @@ void setupOneModeObservations(const std::string& name, SEXP ONEMODES,
 	int observations = Rf_length(ONEMODES);
 	if (observations != pOneModeNetworkLongitudinalData->observationCount())
 	{
-		error(("wrong number of observations in: " + name + ": expected "
-				+ toString(pOneModeNetworkLongitudinalData->observationCount()) + " got "
-				+ toString(observations)).c_str());
+		Rf_error("wrong number of observations for one-mode network");
 	}
 	SEXP uo;
-	PROTECT(uo = install("uponly"));
-	SEXP uponly = getAttrib(ONEMODES, uo);
+	PROTECT(uo = Rf_install("uponly"));
+	SEXP uponly = Rf_getAttrib(ONEMODES, uo);
 	SEXP dow;
-	PROTECT(dow = install("downonly"));
-	SEXP downonly = getAttrib(ONEMODES, dow);
+	PROTECT(dow = Rf_install("downonly"));
+	SEXP downonly = Rf_getAttrib(ONEMODES, dow);
 
 	for (int period = 0; period < (observations - 1); period++)
 	{
@@ -452,32 +450,32 @@ void setupOneModeGroup(SEXP ONEMODEGROUP, Data * pData)
 	for (int oneMode = 0; oneMode < nOneMode; oneMode++)
 	{
 		SEXP ONEMODES = VECTOR_ELT(ONEMODEGROUP, oneMode);
-		SEXP as = PROTECT(install("nodeSet"));
-		SEXP actorSet = PROTECT(getAttrib(ONEMODES, as));
-		SEXP symm = PROTECT(install("symmetric"));
-		SEXP symmetric = PROTECT(getAttrib(ONEMODES, symm));
-		SEXP balm = PROTECT(install("balmean"));
-		SEXP balmean = PROTECT(getAttrib(ONEMODES, balm));
-		SEXP strm = PROTECT(install("structmean"));
-		SEXP structmean = PROTECT(getAttrib(ONEMODES, strm));
-		SEXP avin = PROTECT(install("averageInDegree"));
-		SEXP averageInDegree = PROTECT(getAttrib(ONEMODES, avin));
-		SEXP avout = PROTECT(install("averageOutDegree"));
-		SEXP averageOutDegree = PROTECT(getAttrib(ONEMODES, avout));
+		SEXP as = PROTECT(Rf_install("nodeSet"));
+		SEXP actorSet = PROTECT(Rf_getAttrib(ONEMODES, as));
+		SEXP symm = PROTECT(Rf_install("symmetric"));
+		SEXP symmetric = PROTECT(Rf_getAttrib(ONEMODES, symm));
+		SEXP balm = PROTECT(Rf_install("balmean"));
+		SEXP balmean = PROTECT(Rf_getAttrib(ONEMODES, balm));
+		SEXP strm = PROTECT(Rf_install("structmean"));
+		SEXP structmean = PROTECT(Rf_getAttrib(ONEMODES, strm));
+		SEXP avin = PROTECT(Rf_install("averageInDegree"));
+		SEXP averageInDegree = PROTECT(Rf_getAttrib(ONEMODES, avin));
+		SEXP avout = PROTECT(Rf_install("averageOutDegree"));
+		SEXP averageOutDegree = PROTECT(Rf_getAttrib(ONEMODES, avout));
 
-		SEXP nm = PROTECT(install("name"));
-		SEXP name = getAttrib(ONEMODES, nm);
+		SEXP nm = PROTECT(Rf_install("name"));
+		SEXP name = Rf_getAttrib(ONEMODES, nm);
 		const ActorSet* pActorSet = pData->pActorSet(CHAR(STRING_ELT(actorSet, 0)));
 		const char* cname = CHAR(STRING_ELT(name, 0));
 		OneModeNetworkLongitudinalData *  pNetData = pData->createOneModeNetworkData(cname, pActorSet);
 
 		// parse settings
-		SEXP settingsSymbol = PROTECT(install("settingsinfo"));
-		SEXP settingsList = PROTECT(getAttrib(ONEMODES, settingsSymbol));
+		SEXP settingsSymbol = PROTECT(Rf_install("settingsinfo"));
+		SEXP settingsList = PROTECT(Rf_getAttrib(ONEMODES, settingsSymbol));
 		for (int j = 0; j < Rf_length(settingsList); j++)
 		{
 			SEXP settingInfo = VECTOR_ELT(settingsList, j);
-			SEXP infoNames = getAttrib(settingInfo, R_NamesSymbol);
+			SEXP infoNames = Rf_getAttrib(settingInfo, R_NamesSymbol);
 			std::string id, type, covar, only;
 //			Rprintf("setting %d\n", j);
 			// parse key value list
@@ -496,8 +494,8 @@ void setupOneModeGroup(SEXP ONEMODEGROUP, Data * pData)
 			if      (only == "up")   permType = Permission_Type::UP;
 			else if (only == "down") permType = Permission_Type::DOWN;
 			// asserts
-			if (id.length() == 0) error("settings id should not be empty");
-			if (type.length() == 0) error("settings type should not be empty");
+			if (id.length() == 0) Rf_error("settings id should not be empty");
+			if (type.length() == 0) Rf_error("settings type should not be empty");
 			// add it
 			Rprintf("%s %s %s %s\n", id.c_str(), type.c_str(), covar.c_str(), only.c_str());
 			pNetData->addSettingName(id, type, covar, permType);
@@ -505,12 +503,12 @@ void setupOneModeGroup(SEXP ONEMODEGROUP, Data * pData)
 
 		// check first two setting types
 		if (pNetData->rSettingNames().size() == 1) {
-			error("if setting are present use universal and primary");
+			Rf_error("if setting are present use universal and primary");
 		} else if (pNetData->rSettingNames().size() >= 2) {
 			if (pNetData->rSettingNames().at(0).getSettingType() != "universal")
-				error("first setting should be type=universal");
+				Rf_error("first setting should be type=universal");
 			if (pNetData->rSettingNames().at(1).getSettingType() != "primary")
-				error("second setting should be type=primary");
+				Rf_error("second setting should be type=primary");
 		}
 
 		pNetData->symmetric(*(LOGICAL(symmetric)));
@@ -566,7 +564,7 @@ void setupBipartiteNetwork(SEXP BIPARTITE,
 
 	SEXP BIPARTITEVALS = VECTOR_ELT(BIPARTITE, 0);
 	int *start = INTEGER(BIPARTITEVALS);
-	int listlen = ncols(BIPARTITEVALS);
+	int listlen = Rf_ncols(BIPARTITEVALS);
 	int pos = 0;
 
 	for (int row = 0; row < listlen; row++)
@@ -584,7 +582,7 @@ void setupBipartiteNetwork(SEXP BIPARTITE,
 
 	BIPARTITEVALS = VECTOR_ELT(BIPARTITE, 1);
 	start = INTEGER(BIPARTITEVALS);
-	listlen = ncols(BIPARTITEVALS);
+	listlen = Rf_ncols(BIPARTITEVALS);
 	pos = 0;
 
 	for (int row = 0; row < listlen; row++)
@@ -602,7 +600,7 @@ void setupBipartiteNetwork(SEXP BIPARTITE,
 
 	BIPARTITEVALS = VECTOR_ELT(BIPARTITE, 2);
 	start = INTEGER(BIPARTITEVALS);
-	listlen = ncols(BIPARTITEVALS);
+	listlen = Rf_ncols(BIPARTITEVALS);
 	pos = 0;
 
 	for (int row = 0; row < listlen; row++)
@@ -630,14 +628,14 @@ void setupBipartiteObservations(SEXP BIPARTITES,
     int observations = Rf_length(BIPARTITES);
     if (observations != pNetworkLongitudinalData->observationCount())
     {
-		error ("wrong number of observations in bipartite");
+		Rf_error ("wrong number of observations in bipartite");
     }
     SEXP uo;
-    PROTECT(uo = install("uponly"));
-    SEXP uponly = getAttrib(BIPARTITES, uo);
+    PROTECT(uo = Rf_install("uponly"));
+    SEXP uponly = Rf_getAttrib(BIPARTITES, uo);
     SEXP dow;
-    PROTECT(dow = install("downonly"));
-    SEXP downonly = getAttrib(BIPARTITES, dow);
+    PROTECT(dow = Rf_install("downonly"));
+    SEXP downonly = Rf_getAttrib(BIPARTITES, dow);
     for (int period = 0; period < (observations - 1); period++)
     {
         pNetworkLongitudinalData->upOnly(period,
@@ -664,14 +662,14 @@ void setupBipartiteGroup(SEXP BIPARTITEGROUP, Data * pData)
 	for (int bipartite = 0; bipartite < nBipartite; bipartite++)
 	{
 		SEXP as;
-		PROTECT(as = install("nodeSet"));
-		SEXP actorSet = getAttrib(VECTOR_ELT(BIPARTITEGROUP, bipartite), as);
+		PROTECT(as = Rf_install("nodeSet"));
+		SEXP actorSet = Rf_getAttrib(VECTOR_ELT(BIPARTITEGROUP, bipartite), as);
 		SEXP nm;
-		PROTECT(nm = install("name"));
-		SEXP name = getAttrib(VECTOR_ELT(BIPARTITEGROUP, bipartite), nm);
+		PROTECT(nm = Rf_install("name"));
+		SEXP name = Rf_getAttrib(VECTOR_ELT(BIPARTITEGROUP, bipartite), nm);
 		SEXP avout;
-		PROTECT(avout = install("averageOutDegree"));
-		SEXP averageOutDegree = getAttrib(VECTOR_ELT(BIPARTITEGROUP,
+		PROTECT(avout = Rf_install("averageOutDegree"));
+		SEXP averageOutDegree = Rf_getAttrib(VECTOR_ELT(BIPARTITEGROUP,
 					bipartite), avout);
 		const ActorSet * pSenders = pData->pActorSet(CHAR(STRING_ELT(
 						actorSet, 0)));
@@ -698,17 +696,17 @@ void setupBipartiteGroup(SEXP BIPARTITEGROUP, Data * pData)
  */
 void setupBehavior(SEXP BEHAVIOR, BehaviorLongitudinalData * pBehaviorData)
 {
-	int observations = ncols(VECTOR_ELT(BEHAVIOR, 0));
+	int observations = Rf_ncols(VECTOR_ELT(BEHAVIOR, 0));
 
 	if (observations != pBehaviorData->observationCount())
 	{
-		error ("wrong number of observations in Behavior");
+		Rf_error ("wrong number of observations in Behavior");
 	}
-	int nActors = nrows(VECTOR_ELT(BEHAVIOR, 0));
+	int nActors = Rf_nrows(VECTOR_ELT(BEHAVIOR, 0));
 
 	if (nActors != pBehaviorData->n())
 	{
-		error ("wrong number of actors");
+		Rf_error ("wrong number of actors");
 	}
 	int * start = INTEGER(VECTOR_ELT(BEHAVIOR, 0));
 	int * missing = LOGICAL(VECTOR_ELT(BEHAVIOR, 1));
@@ -722,25 +720,25 @@ void setupBehavior(SEXP BEHAVIOR, BehaviorLongitudinalData * pBehaviorData)
 		}
 	}
 	SEXP uo;
-	PROTECT(uo = install("uponly"));
-	SEXP uponly = getAttrib(VECTOR_ELT(BEHAVIOR, 0), uo);
+	PROTECT(uo = Rf_install("uponly"));
+	SEXP uponly = Rf_getAttrib(VECTOR_ELT(BEHAVIOR, 0), uo);
 	SEXP dow;
-	PROTECT(dow = install("downonly"));
-	SEXP downonly = getAttrib(VECTOR_ELT(BEHAVIOR,0), dow);
+	PROTECT(dow = Rf_install("downonly"));
+	SEXP downonly = Rf_getAttrib(VECTOR_ELT(BEHAVIOR,0), dow);
 	for (int period = 0; period < (observations - 1); period++)
 	{
 		pBehaviorData->upOnly(period, LOGICAL(uponly)[period]);
 		pBehaviorData->downOnly(period, LOGICAL(downonly)[period]);
 	}
 	SEXP sim;
-	PROTECT(sim = install("simMean"));
-	SEXP simMean = getAttrib(VECTOR_ELT(BEHAVIOR,0), sim);
+	PROTECT(sim = Rf_install("simMean"));
+	SEXP simMean = Rf_getAttrib(VECTOR_ELT(BEHAVIOR,0), sim);
 	pBehaviorData->similarityMean(REAL(simMean)[0]);
 	SEXP sims;
-	PROTECT(sims = install("simMeans"));
-	SEXP simMeans = getAttrib(VECTOR_ELT(BEHAVIOR, 0), sims);
+	PROTECT(sims = Rf_install("simMeans"));
+	SEXP simMeans = Rf_getAttrib(VECTOR_ELT(BEHAVIOR, 0), sims);
 	SEXP simNames;
-	PROTECT(simNames = getAttrib(simMeans, R_NamesSymbol));
+	PROTECT(simNames = Rf_getAttrib(simMeans, R_NamesSymbol));
 	int numberNetworks = Rf_length(simMeans);
 	for (int net = 0; net < numberNetworks; net++)
 	{
@@ -764,13 +762,13 @@ void setupBehaviorGroup(SEXP BEHGROUP, Data *pData)
 	for (int behavior= 0; behavior < nBehavior; behavior++)
 	{
 		SEXP as;
-		PROTECT(as = install("nodeSet"));
-		SEXP actorSet = getAttrib(VECTOR_ELT(VECTOR_ELT(BEHGROUP, behavior), 0),
+		PROTECT(as = Rf_install("nodeSet"));
+		SEXP actorSet = Rf_getAttrib(VECTOR_ELT(VECTOR_ELT(BEHGROUP, behavior), 0),
 				as);
 
 		SEXP nm;
-		PROTECT(nm = install("name"));
-		SEXP name = getAttrib(VECTOR_ELT(VECTOR_ELT(BEHGROUP, behavior), 0),
+		PROTECT(nm = Rf_install("name"));
+		SEXP name = Rf_getAttrib(VECTOR_ELT(VECTOR_ELT(BEHGROUP, behavior), 0),
 				nm);
 
 		const ActorSet * pActorSet = pData->pActorSet(CHAR(STRING_ELT(
@@ -787,20 +785,20 @@ void setupBehaviorGroup(SEXP BEHGROUP, Data *pData)
  * Create all observations for a continuous dependent variable
  *
  */
-void setupContinuous(SEXP CONTINUOUS, ContinuousLongitudinalData * 
+void setupContinuous(SEXP CONTINUOUS, ContinuousLongitudinalData *
 	pContinuousData)
 {
-    int observations = ncols(VECTOR_ELT(CONTINUOUS, 0));
+    int observations = Rf_ncols(VECTOR_ELT(CONTINUOUS, 0));
 
     if (observations != pContinuousData->observationCount())
     {
-		error ("wrong number of observations in Continuous");
+		Rf_error ("wrong number of observations in Continuous");
     }
-    int nActors = nrows(VECTOR_ELT(CONTINUOUS, 0));
+    int nActors = Rf_nrows(VECTOR_ELT(CONTINUOUS, 0));
 
     if (nActors != pContinuousData->n())
     {
-        error ("wrong number of actors");
+        Rf_error ("wrong number of actors");
     }
     double * start = REAL(VECTOR_ELT(CONTINUOUS, 0));
 	int * missing = LOGICAL(VECTOR_ELT(CONTINUOUS, 1));
@@ -814,25 +812,25 @@ void setupContinuous(SEXP CONTINUOUS, ContinuousLongitudinalData *
         }
     }
     SEXP uo;
-    PROTECT(uo = install("uponly"));
-    SEXP uponly = getAttrib(VECTOR_ELT(CONTINUOUS, 0), uo);
+    PROTECT(uo = Rf_install("uponly"));
+    SEXP uponly = Rf_getAttrib(VECTOR_ELT(CONTINUOUS, 0), uo);
     SEXP dow;
-    PROTECT(dow = install("downonly"));
-    SEXP downonly = getAttrib(VECTOR_ELT(CONTINUOUS,0), dow);
+    PROTECT(dow = Rf_install("downonly"));
+    SEXP downonly = Rf_getAttrib(VECTOR_ELT(CONTINUOUS,0), dow);
     for (int period = 0; period < (observations - 1); period++)
     {
         pContinuousData->upOnly(period, LOGICAL(uponly)[period]);
         pContinuousData->downOnly(period, LOGICAL(downonly)[period]);
     }
     SEXP sim;
-    PROTECT(sim = install("simMean"));
-    SEXP simMean = getAttrib(VECTOR_ELT(CONTINUOUS,0), sim);
+    PROTECT(sim = Rf_install("simMean"));
+    SEXP simMean = Rf_getAttrib(VECTOR_ELT(CONTINUOUS,0), sim);
 	pContinuousData->similarityMean(REAL(simMean)[0]);
 	SEXP sims;
-	PROTECT(sims = install("simMeans"));
-	SEXP simMeans = getAttrib(VECTOR_ELT(CONTINUOUS, 0), sims);
+	PROTECT(sims = Rf_install("simMeans"));
+	SEXP simMeans = Rf_getAttrib(VECTOR_ELT(CONTINUOUS, 0), sims);
 	SEXP simNames;
-	PROTECT(simNames = getAttrib(simMeans, R_NamesSymbol));
+	PROTECT(simNames = Rf_getAttrib(simMeans, R_NamesSymbol));
 	int numberNetworks = Rf_length(simMeans);
 	for (int net = 0; net < numberNetworks; net++)
 	{
@@ -855,13 +853,13 @@ void setupContinuousGroup(SEXP CONTGROUP, Data *pData)
     for (int continuous = 0; continuous < nCont; continuous++)
     {
 		SEXP as;
-		PROTECT(as = install("nodeSet"));
-        SEXP actorSet = getAttrib(VECTOR_ELT(VECTOR_ELT(CONTGROUP, continuous), 0),
+		PROTECT(as = Rf_install("nodeSet"));
+        SEXP actorSet = Rf_getAttrib(VECTOR_ELT(VECTOR_ELT(CONTGROUP, continuous), 0),
 								  as);
 
         SEXP nm;
-        PROTECT(nm = install("name"));
-        SEXP name = getAttrib(VECTOR_ELT(VECTOR_ELT(CONTGROUP, continuous), 0),
+        PROTECT(nm = Rf_install("name"));
+        SEXP name = Rf_getAttrib(VECTOR_ELT(VECTOR_ELT(CONTGROUP, continuous), 0),
 							  nm);
 
         const ActorSet * myActorSet = pData->pActorSet(CHAR(STRING_ELT(
@@ -883,21 +881,21 @@ void setupConstantCovariate(SEXP COCOVAR,
 	// Rprintf("%x\n", pConstantCovariate);
 	double * start = REAL(COCOVAR);
 	SEXP mn;
-	PROTECT(mn = install("mean"));
-	SEXP ans = getAttrib(COCOVAR, mn);
+	PROTECT(mn = Rf_install("mean"));
+	SEXP ans = Rf_getAttrib(COCOVAR, mn);
 	double mean = REAL(ans)[0];
 	SEXP cn;
-	PROTECT(cn = install("centered"));
-	ans = getAttrib(COCOVAR, cn);
+	PROTECT(cn = Rf_install("centered"));
+	ans = Rf_getAttrib(COCOVAR, cn);
 	bool centered = LOGICAL(ans)[0];
 
 	// extract imputationValues if provided by user
 	SEXP im;
-	PROTECT(im = install("imputationValues"));
-	ans = getAttrib(COCOVAR, im);
+	PROTECT(im = Rf_install("imputationValues"));
+	ans = Rf_getAttrib(COCOVAR, im);
 	bool impute = FALSE;
 	double * imputationValues;
-	if(!isNull(ans))
+	if(!Rf_isNull(ans))
 	{
 		impute = TRUE;
 		imputationValues = REAL(ans);
@@ -948,12 +946,12 @@ void setupConstantCovariateGroup(SEXP COCOVARGROUP, Data *pData)
 			constantCovariate++)
 	{
 		SEXP as;
-		PROTECT(as = install("nodeSet"));
-		SEXP actorSet = getAttrib(VECTOR_ELT(COCOVARGROUP, constantCovariate),
+		PROTECT(as = Rf_install("nodeSet"));
+		SEXP actorSet = Rf_getAttrib(VECTOR_ELT(COCOVARGROUP, constantCovariate),
 				as);
 		SEXP nm;
-		PROTECT(nm = install("name"));
-		SEXP name = getAttrib(VECTOR_ELT(COCOVARGROUP, constantCovariate), nm);
+		PROTECT(nm = Rf_install("name"));
+		SEXP name = Rf_getAttrib(VECTOR_ELT(COCOVARGROUP, constantCovariate), nm);
 		const ActorSet * pActorSet = pData->pActorSet(CHAR(STRING_ELT(
 						actorSet, 0)));
 		int nActors = Rf_length(VECTOR_ELT(COCOVARGROUP, constantCovariate));
@@ -961,7 +959,7 @@ void setupConstantCovariateGroup(SEXP COCOVARGROUP, Data *pData)
 
 		if (nActors != pActorSet->n())
 		{
-			error ("wrong number of actors");
+			Rf_error ("wrong number of actors");
 		}
 		ConstantCovariate * pConstantCovariate =
 			pData->createConstantCovariate(CHAR(STRING_ELT(name, 0)),
@@ -969,11 +967,11 @@ void setupConstantCovariateGroup(SEXP COCOVARGROUP, Data *pData)
 		setupConstantCovariate(VECTOR_ELT(COCOVARGROUP,	constantCovariate),
 				pConstantCovariate);
 		SEXP mn;
-		PROTECT(mn = install("mean"));
-		SEXP obsmean = getAttrib(VECTOR_ELT(COCOVARGROUP, constantCovariate), mn);
+		PROTECT(mn = Rf_install("mean"));
+		SEXP obsmean = Rf_getAttrib(VECTOR_ELT(COCOVARGROUP, constantCovariate), mn);
 		SEXP cn;
-		PROTECT(cn = install("centered"));
-		SEXP ans = getAttrib(VECTOR_ELT(COCOVARGROUP, constantCovariate), cn);
+		PROTECT(cn = Rf_install("centered"));
+		SEXP ans = Rf_getAttrib(VECTOR_ELT(COCOVARGROUP, constantCovariate), cn);
 		bool centered = LOGICAL(ans)[0];
 		if (centered)
 		{
@@ -984,16 +982,16 @@ void setupConstantCovariateGroup(SEXP COCOVARGROUP, Data *pData)
 			pConstantCovariate->mean(REAL(obsmean)[0]);
 		}
 		SEXP sim;
-		PROTECT(sim = install("simMean"));
-		SEXP simMean = getAttrib(VECTOR_ELT(COCOVARGROUP, constantCovariate),
+		PROTECT(sim = Rf_install("simMean"));
+		SEXP simMean = Rf_getAttrib(VECTOR_ELT(COCOVARGROUP, constantCovariate),
 				sim);
 		pConstantCovariate->similarityMean(REAL(simMean)[0]);
 		SEXP sims;
-		PROTECT(sims = install("simMeans"));
-		SEXP simMeans = getAttrib(VECTOR_ELT(COCOVARGROUP, constantCovariate),
+		PROTECT(sims = Rf_install("simMeans"));
+		SEXP simMeans = Rf_getAttrib(VECTOR_ELT(COCOVARGROUP, constantCovariate),
 				sims);
 		SEXP simNames;
-		PROTECT(simNames = getAttrib(simMeans, R_NamesSymbol));
+		PROTECT(simNames = Rf_getAttrib(simMeans, R_NamesSymbol));
 		int numberNetworks = Rf_length(simMeans);
 		for (int net = 0; net < numberNetworks; net++)
 		{
@@ -1001,8 +999,8 @@ void setupConstantCovariateGroup(SEXP COCOVARGROUP, Data *pData)
 					CHAR(STRING_ELT(simNames, net)));
 		}
 		SEXP range;
-		PROTECT(range = install("range"));
-		SEXP Range = getAttrib(VECTOR_ELT(COCOVARGROUP, constantCovariate),
+		PROTECT(range = Rf_install("range"));
+		SEXP Range = Rf_getAttrib(VECTOR_ELT(COCOVARGROUP, constantCovariate),
 				range);
 		pConstantCovariate->range(REAL(Range)[0]);
 		UNPROTECT(8);
@@ -1016,25 +1014,25 @@ void setupConstantCovariateGroup(SEXP COCOVARGROUP, Data *pData)
 void setupChangingCovariate(SEXP VARCOVAR,
 		ChangingCovariate * pChangingCovariate)
 {
-	int observations = ncols(VARCOVAR);
-	int nActors = nrows(VARCOVAR);
+	int observations = Rf_ncols(VARCOVAR);
+	int nActors = Rf_nrows(VARCOVAR);
 	double * start = REAL(VARCOVAR);
 	SEXP mn;
-	PROTECT(mn = install("mean"));
-	SEXP ans = getAttrib(VARCOVAR, mn);
+	PROTECT(mn = Rf_install("mean"));
+	SEXP ans = Rf_getAttrib(VARCOVAR, mn);
 	double mean = REAL(ans)[0];
 	SEXP cn;
-	PROTECT(cn = install("centered"));
-	ans = getAttrib(VARCOVAR, cn);
+	PROTECT(cn = Rf_install("centered"));
+	ans = Rf_getAttrib(VARCOVAR, cn);
 	bool centered = LOGICAL(ans)[0];
 
 	// extract imputationValues if provided by user
 	SEXP im;
-	PROTECT(im = install("imputationValues"));
-	ans = getAttrib(VARCOVAR, im);
+	PROTECT(im = Rf_install("imputationValues"));
+	ans = Rf_getAttrib(VARCOVAR, im);
 	bool impute = FALSE;
 	double * imputationValues = 0;
-	if(!isNull(ans))
+	if(!Rf_isNull(ans))
 	{
 		impute = TRUE;
 		imputationValues = REAL(ans);
@@ -1091,31 +1089,31 @@ void setupChangingCovariateGroup(SEXP VARCOVARGROUP, Data *pData)
 {
 	if (Rf_length(VARCOVARGROUP) == 0)
 		return;
-	int observations = ncols(VECTOR_ELT(VARCOVARGROUP,0));
+	int observations = Rf_ncols(VECTOR_ELT(VARCOVARGROUP,0));
 	if (observations != pData->observationCount() - 1)
 	{
-		error ("wrong number of observations in Changing Covariate");
+		Rf_error ("wrong number of observations in Changing Covariate");
 	}
 	int nChangingCovariate = Rf_length(VARCOVARGROUP);
 	for (int changingCovariate = 0;
 			changingCovariate < nChangingCovariate;
 			changingCovariate++)
-	{		
+	{
 		SEXP as;
-		PROTECT(as = install("nodeSet"));
-		SEXP actorSet = getAttrib(VECTOR_ELT(VARCOVARGROUP, changingCovariate),
+		PROTECT(as = Rf_install("nodeSet"));
+		SEXP actorSet = Rf_getAttrib(VECTOR_ELT(VARCOVARGROUP, changingCovariate),
 				as);
 		SEXP nm;
-		PROTECT(nm = install("name"));
-		SEXP name = getAttrib(VECTOR_ELT(VARCOVARGROUP, changingCovariate),
+		PROTECT(nm = Rf_install("name"));
+		SEXP name = Rf_getAttrib(VECTOR_ELT(VARCOVARGROUP, changingCovariate),
 				nm);
 		const ActorSet * pActorSet = pData->pActorSet(CHAR(STRING_ELT(
 						actorSet, 0)));
-		int nActors = nrows(VECTOR_ELT(VARCOVARGROUP,changingCovariate));
+		int nActors = Rf_nrows(VECTOR_ELT(VARCOVARGROUP,changingCovariate));
 
 		if (nActors != pActorSet->n())
 		{
-			error ("wrong number of actors");
+			Rf_error ("wrong number of actors");
 		}
 		ChangingCovariate * pChangingCovariate =
 			pData->createChangingCovariate(CHAR(STRING_ELT(name, 0)),
@@ -1123,11 +1121,11 @@ void setupChangingCovariateGroup(SEXP VARCOVARGROUP, Data *pData)
 		setupChangingCovariate(VECTOR_ELT(VARCOVARGROUP, changingCovariate),
 				pChangingCovariate);
 		SEXP mn;
-		PROTECT(mn = install("mean"));
-		SEXP obsmean = getAttrib(VECTOR_ELT(VARCOVARGROUP, changingCovariate), mn);
+		PROTECT(mn = Rf_install("mean"));
+		SEXP obsmean = Rf_getAttrib(VECTOR_ELT(VARCOVARGROUP, changingCovariate), mn);
 		SEXP cn;
-		PROTECT(cn = install("centered"));
-		SEXP ans = getAttrib(VECTOR_ELT(VARCOVARGROUP, changingCovariate), cn);
+		PROTECT(cn = Rf_install("centered"));
+		SEXP ans = Rf_getAttrib(VECTOR_ELT(VARCOVARGROUP, changingCovariate), cn);
 		bool centered = LOGICAL(ans)[0];
 		if (centered)
 		{
@@ -1138,16 +1136,16 @@ void setupChangingCovariateGroup(SEXP VARCOVARGROUP, Data *pData)
 			pChangingCovariate->mean(REAL(obsmean)[0]);
 		}
 		SEXP sim;
-		PROTECT(sim = install("simMean"));
-		SEXP simMean = getAttrib(VECTOR_ELT(VARCOVARGROUP, changingCovariate),
+		PROTECT(sim = Rf_install("simMean"));
+		SEXP simMean = Rf_getAttrib(VECTOR_ELT(VARCOVARGROUP, changingCovariate),
 				sim);
 		pChangingCovariate->similarityMean(REAL(simMean)[0]);
 		SEXP sims;
-		PROTECT(sims = install("simMeans"));
-		SEXP simMeans = getAttrib(VECTOR_ELT(VARCOVARGROUP, changingCovariate),
+		PROTECT(sims = Rf_install("simMeans"));
+		SEXP simMeans = Rf_getAttrib(VECTOR_ELT(VARCOVARGROUP, changingCovariate),
 				sims);
 		SEXP simNames;
-		PROTECT(simNames = getAttrib(simMeans, R_NamesSymbol));
+		PROTECT(simNames = Rf_getAttrib(simMeans, R_NamesSymbol));
 		int numberNetworks = Rf_length(simMeans);
 		for (int net = 0; net < numberNetworks; net++)
 		{
@@ -1155,11 +1153,11 @@ void setupChangingCovariateGroup(SEXP VARCOVARGROUP, Data *pData)
 					CHAR(STRING_ELT(simNames, net)));
 		}
 		SEXP range;
-		PROTECT(range = install("range"));
-		SEXP Range = getAttrib(VECTOR_ELT(VARCOVARGROUP, changingCovariate),
+		PROTECT(range = Rf_install("range"));
+		SEXP Range = Rf_getAttrib(VECTOR_ELT(VARCOVARGROUP, changingCovariate),
 				range);
 		pChangingCovariate->range(REAL(Range)[0]);
-		UNPROTECT(8);		
+		UNPROTECT(8);
 	}
 }
 
@@ -1172,7 +1170,7 @@ void setupDyadicCovariate(SEXP DYADVAR,
 {
 	double *start = REAL(VECTOR_ELT(DYADVAR, 0));
 	double *missingstart = REAL(VECTOR_ELT(DYADVAR, 1));
-	int listlen = ncols(VECTOR_ELT(DYADVAR, 0));
+	int listlen = Rf_ncols(VECTOR_ELT(DYADVAR, 0));
 	//	Rprintf("listlen =  %d\n", listlen);
 	int pos = 0;
 	for (int row = 0; row < listlen; row++)
@@ -1185,7 +1183,7 @@ void setupDyadicCovariate(SEXP DYADVAR,
 		val = start[pos++];
 		pConstantDyadicCovariate->value(i-1, j-1, val);
 	}
-	listlen = ncols(VECTOR_ELT(DYADVAR, 1));
+	listlen = Rf_ncols(VECTOR_ELT(DYADVAR, 1));
 	pos = 0;
 	for (int row = 0; row < listlen; row++)
 	{
@@ -1211,12 +1209,12 @@ void setupDyadicCovariateGroup(SEXP DYADVARGROUP, Data *pData)
 			dyadicCovariate++)
 	{
 		SEXP as;
-		PROTECT(as = install("nodeSet"));
-		SEXP actorSet = getAttrib(VECTOR_ELT(DYADVARGROUP, dyadicCovariate),
+		PROTECT(as = Rf_install("nodeSet"));
+		SEXP actorSet = Rf_getAttrib(VECTOR_ELT(DYADVARGROUP, dyadicCovariate),
 				as);
 		SEXP nm;
-		PROTECT(nm = install("name"));
-		SEXP name = getAttrib(VECTOR_ELT(DYADVARGROUP, dyadicCovariate),
+		PROTECT(nm = Rf_install("name"));
+		SEXP name = Rf_getAttrib(VECTOR_ELT(DYADVARGROUP, dyadicCovariate),
 				nm);
 		const ActorSet * myActorSet1 = pData->pActorSet(CHAR(STRING_ELT(
 						actorSet, 0)));
@@ -1228,8 +1226,8 @@ void setupDyadicCovariateGroup(SEXP DYADVARGROUP, Data *pData)
 		setupDyadicCovariate(VECTOR_ELT(DYADVARGROUP, dyadicCovariate),
 				pConstantDyadicCovariate);
 		SEXP mean;
-		PROTECT(mean = install("mean"));
-		SEXP Mean = getAttrib(VECTOR_ELT(DYADVARGROUP, dyadicCovariate),
+		PROTECT(mean = Rf_install("mean"));
+		SEXP Mean = Rf_getAttrib(VECTOR_ELT(DYADVARGROUP, dyadicCovariate),
 				mean);
 		pConstantDyadicCovariate->mean(REAL(Mean)[0]);
 		UNPROTECT(3);
@@ -1244,7 +1242,7 @@ void unpackChangingDyadicPeriod(SEXP VARDYADVALS, ChangingDyadicCovariate *
 		pChangingDyadicCovariate, int period)
 {
 	double *start = REAL(VECTOR_ELT(VARDYADVALS, 0));
-	int listlen = ncols(VECTOR_ELT(VARDYADVALS, 0));
+	int listlen = Rf_ncols(VECTOR_ELT(VARDYADVALS, 0));
 	//	Rprintf("listlen =  %d\n", listlen);
 	int pos = 0;
 	for (int row = 0; row < listlen; row++)
@@ -1258,7 +1256,7 @@ void unpackChangingDyadicPeriod(SEXP VARDYADVALS, ChangingDyadicCovariate *
 		pChangingDyadicCovariate->value(i - 1, j - 1, period, val);
 	}
 	double *missingstart = REAL(VECTOR_ELT(VARDYADVALS, 1));
-	listlen = ncols(VECTOR_ELT(VARDYADVALS, 1));
+	listlen = Rf_ncols(VECTOR_ELT(VARDYADVALS, 1));
 	//	Rprintf("listlen =  %d\n", listlen);
 	pos = 0;
 	for (int row = 0; row < listlen; row++)
@@ -1282,7 +1280,7 @@ void setupChangingDyadicObservations(SEXP VARDYAD,
 	int observations = Rf_length(VARDYAD);
 	//   if (observations != pworkLongitudinalData->observationCount())
 	// {
-	//	error ("wrong number of observations in OneMode");
+	//	Rf_error ("wrong number of observations in OneMode");
 	//  }
 	for (int period = 0; period < (observations - 1); period++)
 	{
@@ -1303,11 +1301,11 @@ void setupChangingDyadicCovariateGroup(SEXP VARDYADGROUP, Data * pData)
 			changingDyadic++)
 	{
 		SEXP as;
-		PROTECT(as = install("nodeSet"));
-		SEXP actorSet = getAttrib(VECTOR_ELT(VARDYADGROUP, changingDyadic), as);
+		PROTECT(as = Rf_install("nodeSet"));
+		SEXP actorSet = Rf_getAttrib(VECTOR_ELT(VARDYADGROUP, changingDyadic), as);
 		SEXP nm;
-		PROTECT(nm = install("name"));
-		SEXP name = getAttrib(VECTOR_ELT(VARDYADGROUP, changingDyadic), nm);
+		PROTECT(nm = Rf_install("name"));
+		SEXP name = Rf_getAttrib(VECTOR_ELT(VARDYADGROUP, changingDyadic), nm);
 		const ActorSet * myActorSet1 = pData->pActorSet(CHAR(STRING_ELT(
 						actorSet, 0)));
 		const ActorSet * myActorSet2 = pData->pActorSet(CHAR(STRING_ELT(
@@ -1319,8 +1317,8 @@ void setupChangingDyadicCovariateGroup(SEXP VARDYADGROUP, Data * pData)
 					changingDyadic),
 				pChangingDyadicCovariate);
 		SEXP mean;
-		PROTECT(mean = install("mean"));
-		SEXP Mean = getAttrib(VECTOR_ELT(VARDYADGROUP, changingDyadic),
+		PROTECT(mean = Rf_install("mean"));
+		SEXP Mean = Rf_getAttrib(VECTOR_ELT(VARDYADGROUP, changingDyadic),
 				mean);
 		pChangingDyadicCovariate->mean(REAL(Mean)[0]);
 		UNPROTECT(3);
@@ -1340,8 +1338,8 @@ void setupExogenousEventSet(SEXP EXOGEVENTSET, Data *pData)
 
 	/* first find the actor set */
 	SEXP as;
-	PROTECT(as = install("nodeSet"));
-	SEXP actorSet = getAttrib(EXOGEVENTSET, as);
+	PROTECT(as = Rf_install("nodeSet"));
+	SEXP actorSet = Rf_getAttrib(EXOGEVENTSET, as);
 
 	/* now process the events */
 	SEXP EVENTS = VECTOR_ELT(EXOGEVENTSET, 0);
@@ -1433,7 +1431,7 @@ SEXP createEffects(SEXP EFFECTS, Model *pModel, vector<Data *> * pGroupData,
 
 	/* set up a vector to return the pointers in */
 	SEXP effectPtrs;
-	PROTECT(effectPtrs = allocVector(VECSXP, nEffects));
+	PROTECT(effectPtrs = Rf_allocVector(VECSXP, nEffects));
 
 	for (int i = 0; i < nEffects; i++)
 	{
@@ -1494,13 +1492,13 @@ SEXP createEffects(SEXP EFFECTS, Model *pModel, vector<Data *> * pGroupData,
 				}
 				else
 				{
-					error("setting found for behavior variable %s",
+					Rf_error("setting found for behavior variable %s",
 							networkName);
 				}
 			}
 		}
 		else if (strcmp(effectType, "rate") == 0 &&
-				 strcmp(effectName, "scale") == 0)		
+				 strcmp(effectName, "scale") == 0)
 		{
 			int period = INTEGER(VECTOR_ELT(EFFECTS, periodCol))[i] - 1;
 			if (strcmp(setting, "") == 0)
@@ -1509,7 +1507,7 @@ SEXP createEffects(SEXP EFFECTS, Model *pModel, vector<Data *> * pGroupData,
 			}
 		else
 		{
-				error("setting found for variable %s", networkName);
+				Rf_error("setting found for variable %s", networkName);
 			}
 		}
 		else // no rate or scale effect
@@ -1547,7 +1545,7 @@ SEXP createInteractionEffects(SEXP EFFECTS, Model *pModel,
 
 	/* set up a vector to return the pointers in */
 	SEXP effectPtrs;
-	PROTECT(effectPtrs = allocVector(VECSXP, nEffects));
+	PROTECT(effectPtrs = Rf_allocVector(VECSXP, nEffects));
 
 	for (int i = 0; i < nEffects; i++)
 	{
@@ -1563,7 +1561,7 @@ SEXP createInteractionEffects(SEXP EFFECTS, Model *pModel,
 		EffectInfo * pEffect2 = (EffectInfo *) R_ExternalPtrAddr(
 				VECTOR_ELT(VECTOR_ELT(EFFECTS, intptr2Col), i));
 		EffectInfo * pEffect3 = 0;
-		if (!isNull(VECTOR_ELT(VECTOR_ELT(EFFECTS, intptr3Col), i)))
+		if (!Rf_isNull(VECTOR_ELT(VECTOR_ELT(EFFECTS, intptr3Col), i)))
 		{
 			pEffect3 = (EffectInfo *) R_ExternalPtrAddr(
 					VECTOR_ELT(VECTOR_ELT(EFFECTS, intptr3Col), i));
@@ -1596,8 +1594,8 @@ void getChangeContributionStatistics(SEXP EFFECTSLIST,
 {
 
 	// get the column names from the names attribute
-	SEXP cols = PROTECT(install("names"));
-	SEXP Names = getAttrib(VECTOR_ELT(EFFECTSLIST, 0), cols);
+	SEXP cols = PROTECT(Rf_install("names"));
+	SEXP Names = Rf_getAttrib(VECTOR_ELT(EFFECTSLIST, 0), cols);
 
 	int netTypeCol; /* net type */
 	int nameCol; /* network name */
@@ -1631,7 +1629,7 @@ void getChangeContributionStatistics(SEXP EFFECTSLIST,
 		{
 			const char * effectType = CHAR(STRING_ELT(VECTOR_ELT(EFFECTS, typeCol), i));
 			const char * netType = CHAR(STRING_ELT(VECTOR_ELT(EFFECTS, netTypeCol), i));
-			if(strcmp(netType, "oneMode") == 0 || strcmp(netType, "bipartite") == 0 || 
+			if(strcmp(netType, "oneMode") == 0 || strcmp(netType, "bipartite") == 0 ||
 									strcmp(netType, "behavior") == 0)
 			{
 				// todo At the moment, change contributions cannot be calculated for endowment or creation effects
@@ -1662,8 +1660,8 @@ void getActorStatistics(SEXP EFFECTSLIST,
 {
 
 	// get the column names from the names attribute
-	SEXP cols = PROTECT(install("names"));
-	SEXP Names = getAttrib(VECTOR_ELT(EFFECTSLIST, 0), cols);
+	SEXP cols = PROTECT(Rf_install("names"));
+	SEXP Names = Rf_getAttrib(VECTOR_ELT(EFFECTSLIST, 0), cols);
 
 	int netTypeCol; /* net type */
 	int nameCol; /* network name */
@@ -1727,8 +1725,8 @@ void getStatistics(SEXP EFFECTSLIST,
 
 	// get the column names from the names attribute
 	SEXP cols;
-	PROTECT(cols = install("names"));
-	SEXP Names = getAttrib(VECTOR_ELT(EFFECTSLIST, 0), cols);
+	PROTECT(cols = Rf_install("names"));
+	SEXP Names = Rf_getAttrib(VECTOR_ELT(EFFECTSLIST, 0), cols);
 
 	int netTypeCol; /* net type */
 	int nameCol; /* network name */
@@ -1746,7 +1744,7 @@ void getStatistics(SEXP EFFECTSLIST,
 	int intptr2Col;
 	int intptr3Col;
 	int settingCol;
-	
+
 // Get the column numbers:
 	getColNos(Names, &netTypeCol, &nameCol, &effectCol,
 			&parmCol, &int1Col, &int2Col, &initValCol,
@@ -1954,11 +1952,11 @@ void getStatistics(SEXP EFFECTSLIST,
 						{
 							score =
 								pVariable->logreciprocalDegreeScore(pNetworkVariable);
-						}						
+						}
 						else
 						{
 
-							error("Unexpected rate effect %s\n",
+							Rf_error("Unexpected rate effect %s\n",
 									effectName);
 						}
 					}
@@ -1989,7 +1987,7 @@ void getStatistics(SEXP EFFECTSLIST,
 						}
 						else
 						{
-							error("Unexpected rate effect %s\n",
+							Rf_error("Unexpected rate effect %s\n",
 									effectName);
 						}
 					}
@@ -2037,7 +2035,7 @@ void getStatistics(SEXP EFFECTSLIST,
 						}
 						else
 						{
-							error("No individual covariate named %s.",
+							Rf_error("No individual covariate named %s.",
 									interaction1);
 						}
 					}
@@ -2120,7 +2118,7 @@ void getStatistics(SEXP EFFECTSLIST,
 				}
 				else
 				{
-					error("invalid effect type %s\n", effectType);
+					Rf_error("invalid effect type %s\n", effectType);
 				}
 			}
 			(*rfra)[istore] = statistic;
@@ -2146,8 +2144,8 @@ void getScores(SEXP EFFECTSLIST, int period, int group,
 {
 
 	// get the column names from the names attribute
-	SEXP cols = PROTECT(install("names"));
-	SEXP Names = getAttrib(VECTOR_ELT(EFFECTSLIST, 0), cols);
+	SEXP cols = PROTECT(Rf_install("names"));
+	SEXP Names = Rf_getAttrib(VECTOR_ELT(EFFECTSLIST, 0), cols);
 
 	int netTypeCol; /* net type */
 	int nameCol; /* network name */
@@ -2213,7 +2211,7 @@ void getScores(SEXP EFFECTSLIST, int period, int group,
 				}
 				else
 				{
-					error("Non constant rate effects are not yet %s",
+					Rf_error("Non constant rate effects are not yet %s",
 							"implemented for maximum likelihood.");
 				}
 			}
