@@ -9,11 +9,12 @@
  * generation utilities.
  *****************************************************************************/
 
-#define R_NO_REMAP
 #include "Random.h"
 #include <sys/time.h>
 #include <Rmath.h>
 #include <vector>
+#undef length
+#include <Rinternals.h>
 
 namespace siena
 {
@@ -48,7 +49,7 @@ double nextExponentialQAD(double lambda)
 double nextExponential(double lambda)
 {
 #ifndef STANDALONE
-	return Rf_rexp(1/lambda);
+	return rexp(1/lambda);
 #endif
 }
 
@@ -59,7 +60,7 @@ double nextExponential(double lambda)
 double nextGamma(double shape, double scale)
 {
 #ifndef STANDALONE
-	return Rf_rgamma(shape, scale);
+	return rgamma(shape, scale);
 #endif
 }
 
@@ -71,7 +72,7 @@ double nextGamma(double shape, double scale)
 double nextNormal(double mean, double standardDeviation)
 {
 #ifndef STANDALONE
-	return Rf_rnorm(mean, standardDeviation);
+	return rnorm(mean, standardDeviation);
 #endif
 }
 
@@ -84,7 +85,7 @@ double normalDensity(double value, double mean, double standardDeviation,
 	 int log)
 {
 #ifndef STANDALONE
-	return Rf_dnorm4(value, mean, standardDeviation, log);
+	return dnorm(value, mean, standardDeviation, log);
 #endif
 }
 /**
@@ -145,10 +146,10 @@ int nextIntWithProbabilities(int n, const double * p)
 //    PutRNGstate();
 //    SEXP ans;
 //    PROTECT(ans = findVar(rs, R_GlobalEnv));
-//    this->state = new std::vector<int>(length(ans));
+//    this->state = new std::vector<int>(Rf_length(ans));
 //    /* copy ans to this->state */
 //    int *start = INTEGER(ans);
-//    for (int i = 0; i < length(ans); i++)
+//    for (int i = 0; i < Rf_length(ans); i++)
 //    {
 //        (*(this->state))[i] = *start++;
 //    }
@@ -170,7 +171,7 @@ int nextIntWithProbabilities(int n, const double * p)
 //    PROTECT(ans = allocVector(INTSXP, this->state->size()));
 //    /* copy this->state to ans */
 //    int *start = INTEGER(ans);
-//    for (int i = 0; i < length(ans); i++)
+//    for (int i = 0; i < Rf_length(ans); i++)
 //    {
 //        *start++ = (*(this->state))[i];
 //    }
